Trait bstr::AsRawBStr
[−]
[src]
pub trait AsRawBStr {
fn as_raw(&self) -> BSTR;
}Borrow as raw BSTR.
Use at the FFI boundary, you are responsible for ensuring the raw BSTR does not outlive its owner.
Required Methods
fn as_raw(&self) -> BSTR
Returns the raw BSTR for this type.
Do not mutate or take ownership of the returned BSTR.